marchanddesable
===============

Turn off your server when you sleep.

Usage
-----
Halt the current machines 5 minutes after both 192.168.0.1 and 192.168.0.2 stop pinging::

    marchand 192.168.0.1 192.168.0.2


TODO
----

These features may or may not be implemented at some point :

- Play a sound to warn when the machines stopped pinging
- Do some useful logging

If you want any of those, or anything else, give me a shout.
